/* ver.B.b14.02(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"gbr64",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b14.02(BLAZE)",
	2007,2,27,
	0,
	"GB r64/cr agent ? gbs/doc/xml/man/html/ja-gbview",
};

